// Copyright 2025, ANSYS Inc. Unauthorized use, distribution or duplication is prohibited.
syntax = "proto3";
package ansys.api.discovery.v1;

option csharp_namespace = "Ansys.Api.Discovery.V1";

enum ResultVariable{
  RESULT_VARIABLE_UNSPECIFIED = 0;
  RESULT_VARIABLE_DISPLACEMENT = 1;
  RESULT_VARIABLE_VON_MISES_STRESS = 2;
  RESULT_VARIABLE_TEMPERATURE = 3;
  RESULT_VARIABLE_STRESS = 4;
  RESULT_VARIABLE_PRINCIPAL_STRESS = 5;
  RESULT_VARIABLE_ELASTIC_STRAIN = 6;
  RESULT_VARIABLE_PRINCIPAL_ELASTIC_STRAIN = 7;
  RESULT_VARIABLE_HEAT_FLUX = 8;
  RESULT_VARIABLE_PRESSURE = 9;
  RESULT_VARIABLE_VELOCITY = 10;
  RESULT_VARIABLE_VORTICES_LAMBDA_2 = 11;
  RESULT_VARIABLE_MASS = 12;
  RESULT_VARIABLE_FORCE_REACTION = 13;
  RESULT_VARIABLE_DENSITY = 14;
  RESULT_VARIABLE_FACTOR_OF_SAFETY = 15;
  RESULT_VARIABLE_PRESSURE_DROP = 16;
  RESULT_VARIABLE_CONTACT_REACTION = 17;
  RESULT_VARIABLE_JOINT_TOTAL_FORCE = 18;
  RESULT_VARIABLE_JOINT_TOTAL_MOMENT = 19;
  RESULT_VARIABLE_FREQUENCY = 20;
  RESULT_VARIABLE_MESH_STATISTICS = 21;
  RESULT_VARIABLE_MESH_QUALITY = 22;
  RESULT_VARIABLE_FLUID_FORCE = 23;
  RESULT_VARIABLE_VOLUME = 24;
  RESULT_VARIABLE_VOLUME_FLOW = 25;
  RESULT_VARIABLE_MASS_FLOW = 26;
  RESULT_VARIABLE_HEAT_FLOW = 27;
  RESULT_VARIABLE_TOTAL_PRESSURE = 28;
  RESULT_VARIABLE_FLOW_UNIFORMITY = 29;
  RESULT_VARIABLE_S_PARAMETERS = 30;
  RESULT_VARIABLE_GAIN = 31;
  RESULT_VARIABLE_REALIZED_GAIN = 32;
  RESULT_VARIABLE_DIRECTIVITY = 33;
  RESULT_VARIABLE_AXIAL_RATIO = 34;
  RESULT_VARIABLE_RADIAL_E = 35;
  RESULT_VARIABLE_CONTACT_STRESS = 36;
  RESULT_VARIABLE_MACH_NUMBER = 37;
  RESULT_VARIABLE_ELECTRIC_FIELD = 38;
  RESULT_VARIABLE_MAGNETIC_FIELD = 39;
  RESULT_VARIABLE_CONNECTION_FACTOR_OF_SAFETY = 40;
  RESULT_VARIABLE_AXIAL_STRESS = 41;
  RESULT_VARIABLE_TORSIONAL_MOMENT = 42;
  RESULT_VARIABLE_SHEAR_FORCE = 43;
  RESULT_VARIABLE_ANTENNA_PARAMETERS = 44;
  RESULT_VARIABLE_FAN_PRESSURE_RISE = 45;
  RESULT_VARIABLE_RADIATIVE_HEAT_FLUX = 46;
  RESULT_VARIABLE_VOLTAGE = 47;
  RESULT_VARIABLE_CURRENT_DENSITY = 48;
  RESULT_VARIABLE_JOULE_HEAT = 49;
}

enum ResultFunction{
  RESULT_FUNCTION_UNSPECIFIED = 0;
  RESULT_FUNCTION_MINIMUM = 1;
  RESULT_FUNCTION_MAXIMUM = 2;
  RESULT_FUNCTION_AVERAGE = 3;
  RESULT_FUNCTION_SUM = 4;
  RESULT_FUNCTION_INTEGRAL = 5;
  RESULT_FUNCTION_STANDARD_DEVIATION = 6;
}

enum ResultComponent{
  RESULT_COMPONENT_UNSPECIFIED = 0;
  RESULT_COMPONENT_NONE = 1;
  RESULT_COMPONENT_X = 2;
  RESULT_COMPONENT_Y = 3;
  RESULT_COMPONENT_Z = 4;
  RESULT_COMPONENT_XX = 5;
  RESULT_COMPONENT_YY = 6;
  RESULT_COMPONENT_ZZ = 7;
  RESULT_COMPONENT_YZ = 8;
  RESULT_COMPONENT_XY = 9;
  RESULT_COMPONENT_XZ = 10;
  RESULT_COMPONENT_MAG = 11;
  RESULT_COMPONENT_FIRST = 12;
  RESULT_COMPONENT_SECOND = 13;
  RESULT_COMPONENT_THIRD = 14;
  RESULT_COMPONENT_VELOCITY = 15;
  RESULT_COMPONENT_TEMPERATURE = 16;
  RESULT_COMPONENT_REAL = 17;
  RESULT_COMPONENT_IMAGINARY = 18;
  RESULT_COMPONENT_PHASE = 19;
  RESULT_COMPONENT_LOGARITHMIC_MAG = 20;
  RESULT_COMPONENT_CONJUGATE_PHASE = 21;
  RESULT_COMPONENT_TOTAL = 22;
  RESULT_COMPONENT_L3X = 23;
  RESULT_COMPONENT_L3Y = 24;
  RESULT_COMPONENT_RHCP = 25;
  RESULT_COMPONENT_LHCP = 26;
  RESULT_COMPONENT_THETA = 27;
  RESULT_COMPONENT_PHI = 28;
}