// Copyright 2025, ANSYS Inc. Unauthorized use, distribution or duplication is prohibited.
syntax = "proto3";
package ansys.api.discovery.v0.simulations;

import "ansys/api/discovery/v0/discoverymodels.proto";
import "google/protobuf/empty.proto";

option csharp_namespace = "Ansys.Api.Discovery.V0.Simulations";

service Simulations
{
  // Creates a new simulation
  rpc CreateSimulation(google.protobuf.Empty) returns (Simulation);

  // Lists all simulations
  rpc GetAll(google.protobuf.Empty) returns(GetAllResponse);
}

message GetAllResponse{
  // The simulations in the study.
  repeated Simulation simulations = 1;
}