// Copyright 2025, ANSYS Inc. Unauthorized use, distribution or duplication is prohibited.
syntax = "proto3";
package ansys.api.discovery.v0.conditions;

import "ansys/api/dbu/v0/dbumodels.proto";
import "ansys/api/discovery/v0/discoverymodels.proto";

option csharp_namespace = "Ansys.Api.Discovery.V0.Conditions";

service Condition
{
  //General condition methods
  rpc DeleteCondition(DeleteConditionRequest) returns (ChangeResponse);

  rpc ChangeConditionSuppressionState(ChangeConditionSuppressionStateRequest) returns (ChangeResponse);

  rpc ChangeConditionName(ChangeConditionNameRequest) returns (ChangeResponse);
}

//General Requests
message DeleteConditionRequest{
  ansys.api.dbu.v0.PhysicsEntityIdentifier object_id = 1;
}

message ChangeConditionSuppressionStateRequest{
  ansys.api.dbu.v0.PhysicsEntityIdentifier object_id = 1;
  bool is_suppressed = 2;
}

message ChangeConditionNameRequest{
  ansys.api.dbu.v0.PhysicsEntityIdentifier object_id = 1;
  string new_name = 2;
}

message GetByLabelRequest{
  string label = 1;
}