// Copyright 2025, ANSYS Inc. Unauthorized use, distribution or duplication is prohibited.
syntax = "proto3";
package ansys.api.discovery.v1.design.constructs.datumpoint;

import "ansys/api/discovery/v1/commonmessages.proto";
import "ansys/api/discovery/v1/design/designmessages.proto";

option csharp_namespace = "Ansys.Api.Discovery.V1.Design.Constructs.DatumPoint";

service DatumPoint
{
  rpc Create(DatumPointCreationRequest) returns (DatumPointCreationResponse);

  //TODO: Delete, Get, GetAll
  //TODO: Enable x, y, z location inputs to be set.
}

message DatumPointCreationRequestData {
  repeated DatumPointEntity points = 1;
  EntityIdentifier parent_id = 2;
}

message DatumPointCreationRequest {
  repeated DatumPointCreationRequestData request_data=1;
}

message DatumPointCreationResponse {
  repeated EntityIdentifier ids =1;
  CreationResponse creation_response = 2;
}


