// Copyright 2025, ANSYS Inc. Unauthorized use, distribution or duplication is prohibited.
syntax = "proto3";
package ansys.api.discovery.v1.operations.sketch;

import "ansys/api/discovery/v1/commonmessages.proto";

option csharp_namespace = "Ansys.Api.Discovery.V1.Operations.Sketch";

service Sketch
{  
  rpc CreateSketchLine(CreateSketchLineRequest) returns (CreateSketchLineResponse);
}

message CreateSketchLineRequestData{
  Point point1 = 1;
  Point point2 = 2;
}

message CreateSketchLineRequest{
  repeated CreateSketchLineRequestData request_data = 1;
}

message CreateSketchLineResponse{
  int32 successfully_set = 1;
}

