// Copyright 2025, ANSYS Inc. Unauthorized use, distribution or duplication is prohibited.
syntax = "proto3";
package ansys.api.discovery.v0;
option csharp_namespace = "Ansys.Api.Discovery.V0";

//
// Acceleration units.
enum AccelerationUnit {
  ACCELERATION_CENTIMETER_PER_SECOND_SQUARED=0;
  ACCELERATION_DECIMETER_PER_SECOND_SQUARED=1;
  ACCELERATION_FOOT_PER_SECOND_SQUARED=2;
  ACCELERATION_INCH_PER_SECOND_SQUARED=3;
  ACCELERATION_KILOMETER_PER_SECOND_SQUARED=4;
  ACCELERATION_KNOT_PER_HOUR=5;
  ACCELERATION_KNOT_PER_MINUTE=6;
  ACCELERATION_KNOT_PER_SECOND=7;
  ACCELERATION_METER_PER_SECOND_SQUARED=8;
  ACCELERATION_MICROMETER_PER_SECOND_SQUARED=9;
  ACCELERATION_MILLIMETER_PER_SECOND_SQUARED=10;
  ACCELERATION_NANOMETER_PER_SECOND_SQUARED=11;
  ACCELERATION_STANDARD_GRAVITY=12;
}

//
// Angle units.
enum AngleUnit {
  ANGLE_ARCMINUTE=0;
  ANGLE_ARCSECOND=1;
  ANGLE_CENTIRADIAN=2;
  ANGLE_DECIRADIAN=3;
  ANGLE_DEGREE=4;
  ANGLE_GRADIAN=5;
  ANGLE_MICRODEGREE=6;
  ANGLE_MICRORADIAN=7;
  ANGLE_MILLIDEGREE=8;
  ANGLE_MILLIRADIAN=9;
  ANGLE_NANODEGREE=10;
  ANGLE_NANORADIAN=11;
  ANGLE_RADIAN=12;
  ANGLE_REVOLUTION=13;
}

//
// Area units.
enum AreaUnit {
  AREA_ACRE=0;
  AREA_HECTARE=1;
  AREA_SQUARE_CENTIMETER=2;
  AREA_SQUARE_DECIMETER=3;
  AREA_SQUARE_FOOT=4;
  AREA_SQUARE_INCH=5;
  AREA_SQUARE_KILOMETER=6;
  AREA_SQUARE_METER=7;
  AREA_SQUARE_MICROMETER=8;
  AREA_SQUARE_MILE=9;
  AREA_SQUARE_MILLIMETER=10;
  AREA_SQUARE_NAUTICAL_MILE=11;
  AREA_SQUARE_YARD=12;
  AREA_US_SURVEY_SQUARE_FOOT=13;
}

//
// AreaDensity units.
enum AreaDensityUnit {
  AREADENSITY_KILOGRAM_PER_SQUARE_METER=0;
}

//
// AreaMomentOfInertia units.
enum AreaMomentOfInertiaUnit {
  AREAMOMENTOFINERTIA_CENTIMETER_TO_THE_FOURTH=0;
  AREAMOMENTOFINERTIA_DECIMETER_TO_THE_FOURTH=1;
  AREAMOMENTOFINERTIA_FOOT_TO_THE_FOURTH=2;
  AREAMOMENTOFINERTIA_INCH_TO_THE_FOURTH=3;
  AREAMOMENTOFINERTIA_METER_TO_THE_FOURTH=4;
  AREAMOMENTOFINERTIA_MILLIMETER_TO_THE_FOURTH=5;
}

//
// Capacitance units.
enum CapacitanceUnit {
  CAPACITANCE_FARAD=0;
  CAPACITANCE_KILOFARAD=1;
  CAPACITANCE_MEGAFARAD=2;
  CAPACITANCE_MICROFARAD=3;
  CAPACITANCE_MILLIFARAD=4;
  CAPACITANCE_NANOFARAD=5;
  CAPACITANCE_PICOFARAD=6;
}

//
// CoefficientOfThermalExpansion units.
enum CoefficientOfThermalExpansionUnit {
  COEFFICIENTOFTHERMALEXPANSION_INVERSE_DEGREE_CELSIUS=0;
  COEFFICIENTOFTHERMALEXPANSION_INVERSE_DEGREE_FAHRENHEIT=1;
  COEFFICIENTOFTHERMALEXPANSION_INVERSE_KELVIN=2;
}

//
// Density units.
enum DensityUnit {
  DENSITY_CENTIGRAM_PER_DECILITER=0;
  DENSITY_CENTIGRAM_PER_LITER=1;
  DENSITY_CENTIGRAM_PER_MILLILITER=2;
  DENSITY_DECIGRAM_PER_DECILITER=3;
  DENSITY_DECIGRAM_PER_LITER=4;
  DENSITY_DECIGRAM_PER_MILLILITER=5;
  DENSITY_GRAM_PER_CUBIC_CENTIMETER=6;
  DENSITY_GRAM_PER_CUBIC_METER=7;
  DENSITY_GRAM_PER_CUBIC_MILLIMETER=8;
  DENSITY_GRAM_PER_DECILITER=9;
  DENSITY_GRAM_PER_LITER=10;
  DENSITY_GRAM_PER_MILLILITER=11;
  DENSITY_KILOGRAM_PER_CUBIC_CENTIMETER=12;
  DENSITY_KILOGRAM_PER_CUBIC_METER=13;
  DENSITY_KILOGRAM_PER_CUBIC_MILLIMETER=14;
  DENSITY_KILOGRAM_PER_LITER=15;
  DENSITY_KILOPOUND_PER_CUBIC_FOOT=16;
  DENSITY_KILOPOUND_PER_CUBIC_INCH=17;
  DENSITY_MICROGRAM_PER_CUBIC_METER=18;
  DENSITY_MICROGRAM_PER_DECILITER=19;
  DENSITY_MICROGRAM_PER_LITER=20;
  DENSITY_MICROGRAM_PER_MILLILITER=21;
  DENSITY_MILLIGRAM_PER_CUBIC_METER=22;
  DENSITY_MILLIGRAM_PER_DECILITER=23;
  DENSITY_MILLIGRAM_PER_LITER=24;
  DENSITY_MILLIGRAM_PER_MILLILITER=25;
  DENSITY_NANOGRAM_PER_DECILITER=26;
  DENSITY_NANOGRAM_PER_LITER=27;
  DENSITY_NANOGRAM_PER_MILLILITER=28;
  DENSITY_PICOGRAM_PER_DECILITER=29;
  DENSITY_PICOGRAM_PER_LITER=30;
  DENSITY_PICOGRAM_PER_MILLILITER=31;
  DENSITY_POUND_PER_CUBIC_FOOT=32;
  DENSITY_POUND_PER_CUBIC_INCH=33;
  DENSITY_POUND_PER_IMPERIAL_GALLON=34;
  DENSITY_POUND_PER_U_S_GALLON=35;
  DENSITY_SLUG_PER_CUBIC_FOOT=36;
  DENSITY_TONNE_PER_CUBIC_CENTIMETER=37;
  DENSITY_TONNE_PER_CUBIC_METER=38;
  DENSITY_TONNE_PER_CUBIC_MILLIMETER=39;
}

//
// DynamicViscosity units.
enum DynamicViscosityUnit {
  DYNAMICVISCOSITY_CENTIPOISE=0;
  DYNAMICVISCOSITY_MICROPASCAL_SECOND=1;
  DYNAMICVISCOSITY_MILLIPASCAL_SECOND=2;
  DYNAMICVISCOSITY_NEWTON_SECOND_PER_METER_SQUARED=3;
  DYNAMICVISCOSITY_PASCAL_SECOND=4;
  DYNAMICVISCOSITY_POISE=5;
  DYNAMICVISCOSITY_POUND_FORCE_SECOND_PER_SQUARE_FOOT=6;
  DYNAMICVISCOSITY_POUND_FORCE_SECOND_PER_SQUARE_INCH=7;
  DYNAMICVISCOSITY_REYN=8;
}

//
// ElectricAdmittance units.
enum ElectricAdmittanceUnit {
  ELECTRICADMITTANCE_MICROSIEMENS=0;
  ELECTRICADMITTANCE_MILLISIEMENS=1;
  ELECTRICADMITTANCE_NANOSIEMENS=2;
  ELECTRICADMITTANCE_SIEMENS=3;
}

//
// ElectricCharge units.
enum ElectricChargeUnit {
  ELECTRICCHARGE_AMPERE_HOUR=0;
  ELECTRICCHARGE_COULOMB=1;
  ELECTRICCHARGE_KILOAMPERE_HOUR=2;
  ELECTRICCHARGE_MEGAAMPERE_HOUR=3;
  ELECTRICCHARGE_MILLIAMPERE_HOUR=4;
}

//
// ElectricChargeDensity units.
enum ElectricChargeDensityUnit {
  ELECTRICCHARGEDENSITY_COULOMB_PER_CUBIC_METER=0;
}

//
// ElectricConductance units.
enum ElectricConductanceUnit {
  ELECTRICCONDUCTANCE_MICROSIEMENS=0;
  ELECTRICCONDUCTANCE_MILLISIEMENS=1;
  ELECTRICCONDUCTANCE_SIEMENS=2;
}

//
// ElectricConductivity units.
enum ElectricConductivityUnit {
  ELECTRICCONDUCTIVITY_SIEMENS_PER_FOOT=0;
  ELECTRICCONDUCTIVITY_SIEMENS_PER_INCH=1;
  ELECTRICCONDUCTIVITY_SIEMENS_PER_METER=2;
}

//
// ElectricCurrent units.
enum ElectricCurrentUnit {
  ELECTRICCURRENT_AMPERE=0;
  ELECTRICCURRENT_CENTIAMPERE=1;
  ELECTRICCURRENT_KILOAMPERE=2;
  ELECTRICCURRENT_MEGAAMPERE=3;
  ELECTRICCURRENT_MICROAMPERE=4;
  ELECTRICCURRENT_MILLIAMPERE=5;
  ELECTRICCURRENT_NANOAMPERE=6;
  ELECTRICCURRENT_PICOAMPERE=7;
}

//
// ElectricCurrentDensity units.
enum ElectricCurrentDensityUnit {
  ELECTRICCURRENTDENSITY_AMPERE_PER_SQUARE_FOOT=0;
  ELECTRICCURRENTDENSITY_AMPERE_PER_SQUARE_INCH=1;
  ELECTRICCURRENTDENSITY_AMPERE_PER_SQUARE_METER=2;
}

//
// ElectricCurrentGradient units.
enum ElectricCurrentGradientUnit {
  ELECTRICCURRENTGRADIENT_AMPERE_PER_SECOND=0;
}

//
// ElectricField units.
enum ElectricFieldUnit {
  ELECTRICFIELD_VOLT_PER_METER=0;
}

//
// ElectricInductance units.
enum ElectricInductanceUnit {
  ELECTRICINDUCTANCE_HENRY=0;
  ELECTRICINDUCTANCE_MICROHENRY=1;
  ELECTRICINDUCTANCE_MILLIHENRY=2;
  ELECTRICINDUCTANCE_NANOHENRY=3;
}

//
// ElectricPotential units.
enum ElectricPotentialUnit {
  ELECTRICPOTENTIAL_KILOVOLT=0;
  ELECTRICPOTENTIAL_MEGAVOLT=1;
  ELECTRICPOTENTIAL_MICROVOLT=2;
  ELECTRICPOTENTIAL_MILLIVOLT=3;
  ELECTRICPOTENTIAL_VOLT=4;
}

//
// ElectricPotentialAc units.
enum ElectricPotentialAcUnit {
  ELECTRICPOTENTIALAC_KILOVOLT_AC=0;
  ELECTRICPOTENTIALAC_MEGAVOLT_AC=1;
  ELECTRICPOTENTIALAC_MICROVOLT_AC=2;
  ELECTRICPOTENTIALAC_MILLIVOLT_AC=3;
  ELECTRICPOTENTIALAC_VOLT_AC=4;
}

//
// ElectricPotentialChangeRate units.
enum ElectricPotentialChangeRateUnit {
  ELECTRICPOTENTIALCHANGERATE_KILOVOLT_PER_HOUR=0;
  ELECTRICPOTENTIALCHANGERATE_KILOVOLT_PER_MICROSECOND=1;
  ELECTRICPOTENTIALCHANGERATE_KILOVOLT_PER_MINUTE=2;
  ELECTRICPOTENTIALCHANGERATE_KILOVOLT_PER_SECOND=3;
  ELECTRICPOTENTIALCHANGERATE_MEGAVOLT_PER_HOUR=4;
  ELECTRICPOTENTIALCHANGERATE_MEGAVOLT_PER_MICROSECOND=5;
  ELECTRICPOTENTIALCHANGERATE_MEGAVOLT_PER_MINUTE=6;
  ELECTRICPOTENTIALCHANGERATE_MEGAVOLT_PER_SECOND=7;
  ELECTRICPOTENTIALCHANGERATE_MICROVOLT_PER_HOUR=8;
  ELECTRICPOTENTIALCHANGERATE_MICROVOLT_PER_MICROSECOND=9;
  ELECTRICPOTENTIALCHANGERATE_MICROVOLT_PER_MINUTE=10;
  ELECTRICPOTENTIALCHANGERATE_MICROVOLT_PER_SECOND=11;
  ELECTRICPOTENTIALCHANGERATE_MILLIVOLT_PER_HOUR=12;
  ELECTRICPOTENTIALCHANGERATE_MILLIVOLT_PER_MICROSECOND=13;
  ELECTRICPOTENTIALCHANGERATE_MILLIVOLT_PER_MINUTE=14;
  ELECTRICPOTENTIALCHANGERATE_MILLIVOLT_PER_SECOND=15;
  ELECTRICPOTENTIALCHANGERATE_VOLT_PER_HOUR=16;
  ELECTRICPOTENTIALCHANGERATE_VOLT_PER_MICROSECOND=17;
  ELECTRICPOTENTIALCHANGERATE_VOLT_PER_MINUTE=18;
  ELECTRICPOTENTIALCHANGERATE_VOLT_PER_SECOND=19;
}

//
// ElectricPotentialDc units.
enum ElectricPotentialDcUnit {
  ELECTRICPOTENTIALDC_KILOVOLT_DC=0;
  ELECTRICPOTENTIALDC_MEGAVOLT_DC=1;
  ELECTRICPOTENTIALDC_MICROVOLT_DC=2;
  ELECTRICPOTENTIALDC_MILLIVOLT_DC=3;
  ELECTRICPOTENTIALDC_VOLT_DC=4;
}

//
// ElectricResistance units.
enum ElectricResistanceUnit {
  ELECTRICRESISTANCE_GIGAOHM=0;
  ELECTRICRESISTANCE_KILOOHM=1;
  ELECTRICRESISTANCE_MEGAOHM=2;
  ELECTRICRESISTANCE_MICROOHM=3;
  ELECTRICRESISTANCE_MILLIOHM=4;
  ELECTRICRESISTANCE_OHM=5;
}

//
// ElectricResistivity units.
enum ElectricResistivityUnit {
  ELECTRICRESISTIVITY_KILOOHM_CENTIMETER=0;
  ELECTRICRESISTIVITY_KILOOHM_METER=1;
  ELECTRICRESISTIVITY_MEGAOHM_CENTIMETER=2;
  ELECTRICRESISTIVITY_MEGAOHM_METER=3;
  ELECTRICRESISTIVITY_MICROOHM_CENTIMETER=4;
  ELECTRICRESISTIVITY_MICROOHM_METER=5;
  ELECTRICRESISTIVITY_MILLIOHM_CENTIMETER=6;
  ELECTRICRESISTIVITY_MILLIOHM_METER=7;
  ELECTRICRESISTIVITY_NANOOHM_CENTIMETER=8;
  ELECTRICRESISTIVITY_NANOOHM_METER=9;
  ELECTRICRESISTIVITY_OHM_CENTIMETER=10;
  ELECTRICRESISTIVITY_OHM_METER=11;
  ELECTRICRESISTIVITY_PICOOHM_CENTIMETER=12;
  ELECTRICRESISTIVITY_PICOOHM_METER=13;
}

//
// ElectricSurfaceChargeDensity units.
enum ElectricSurfaceChargeDensityUnit {
  ELECTRICSURFACECHARGEDENSITY_COULOMB_PER_SQUARE_CENTIMETER=0;
  ELECTRICSURFACECHARGEDENSITY_COULOMB_PER_SQUARE_INCH=1;
  ELECTRICSURFACECHARGEDENSITY_COULOMB_PER_SQUARE_METER=2;
}

//
// Energy units.
enum EnergyUnit {
  ENERGY_BRITISH_THERMAL_UNIT=0;
  ENERGY_CALORIE=1;
  ENERGY_DECATHERM_EC=2;
  ENERGY_DECATHERM_IMPERIAL=3;
  ENERGY_DECATHERM_US=4;
  ENERGY_ELECTRON_VOLT=5;
  ENERGY_ERG=6;
  ENERGY_FOOT_POUND=7;
  ENERGY_GIGABRITISH_THERMAL_UNIT=8;
  ENERGY_GIGAELECTRON_VOLT=9;
  ENERGY_GIGAJOULE=10;
  ENERGY_GIGAWATT_DAY=11;
  ENERGY_GIGAWATT_HOUR=12;
  ENERGY_HORSEPOWER_HOUR=13;
  ENERGY_JOULE=14;
  ENERGY_KILOBRITISH_THERMAL_UNIT=15;
  ENERGY_KILOCALORIE=16;
  ENERGY_KILOELECTRON_VOLT=17;
  ENERGY_KILOJOULE=18;
  ENERGY_KILOWATT_DAY=19;
  ENERGY_KILOWATT_HOUR=20;
  ENERGY_MEGABRITISH_THERMAL_UNIT=21;
  ENERGY_MEGACALORIE=22;
  ENERGY_MEGAELECTRON_VOLT=23;
  ENERGY_MEGAJOULE=24;
  ENERGY_MEGAWATT_DAY=25;
  ENERGY_MEGAWATT_HOUR=26;
  ENERGY_MILLIJOULE=27;
  ENERGY_TERAELECTRON_VOLT=28;
  ENERGY_TERAWATT_DAY=29;
  ENERGY_TERAWATT_HOUR=30;
  ENERGY_THERM_EC=31;
  ENERGY_THERM_IMPERIAL=32;
  ENERGY_THERM_US=33;
  ENERGY_WATT_DAY=34;
  ENERGY_WATT_HOUR=35;
}

//
// Entropy units.
enum EntropyUnit {
  ENTROPY_CALORIE_PER_KELVIN=0;
  ENTROPY_JOULE_PER_DEGREE_CELSIUS=1;
  ENTROPY_JOULE_PER_KELVIN=2;
  ENTROPY_KILOCALORIE_PER_KELVIN=3;
  ENTROPY_KILOJOULE_PER_DEGREE_CELSIUS=4;
  ENTROPY_KILOJOULE_PER_KELVIN=5;
  ENTROPY_MEGAJOULE_PER_KELVIN=6;
}

//
// Force units.
enum ForceUnit {
  FORCE_DECANEWTON=0;
  FORCE_DYN=1;
  FORCE_KILOGRAM_FORCE=2;
  FORCE_KILONEWTON=3;
  FORCE_KILO_POND=4;
  FORCE_KILOPOUND_FORCE=5;
  FORCE_MEGANEWTON=6;
  FORCE_MICRONEWTON=7;
  FORCE_MILLINEWTON=8;
  FORCE_NEWTON=9;
  FORCE_OUNCE_FORCE=10;
  FORCE_POUNDAL=11;
  FORCE_POUND_FORCE=12;
  FORCE_TONNE_FORCE=13;
}

//
// ForceChangeRate units.
enum ForceChangeRateUnit {
  FORCECHANGERATE_CENTINEWTON_PER_SECOND=0;
  FORCECHANGERATE_DECANEWTON_PER_MINUTE=1;
  FORCECHANGERATE_DECANEWTON_PER_SECOND=2;
  FORCECHANGERATE_DECINEWTON_PER_SECOND=3;
  FORCECHANGERATE_KILONEWTON_PER_MINUTE=4;
  FORCECHANGERATE_KILONEWTON_PER_SECOND=5;
  FORCECHANGERATE_MICRONEWTON_PER_SECOND=6;
  FORCECHANGERATE_MILLINEWTON_PER_SECOND=7;
  FORCECHANGERATE_NANONEWTON_PER_SECOND=8;
  FORCECHANGERATE_NEWTON_PER_MINUTE=9;
  FORCECHANGERATE_NEWTON_PER_SECOND=10;
}

//
// ForcePerLength units.
enum ForcePerLengthUnit {
  FORCEPERLENGTH_CENTINEWTON_PER_CENTIMETER=0;
  FORCEPERLENGTH_CENTINEWTON_PER_METER=1;
  FORCEPERLENGTH_CENTINEWTON_PER_MILLIMETER=2;
  FORCEPERLENGTH_DECANEWTON_PER_CENTIMETER=3;
  FORCEPERLENGTH_DECANEWTON_PER_METER=4;
  FORCEPERLENGTH_DECANEWTON_PER_MILLIMETER=5;
  FORCEPERLENGTH_DECINEWTON_PER_CENTIMETER=6;
  FORCEPERLENGTH_DECINEWTON_PER_METER=7;
  FORCEPERLENGTH_DECINEWTON_PER_MILLIMETER=8;
  FORCEPERLENGTH_KILOGRAM_FORCE_PER_CENTIMETER=9;
  FORCEPERLENGTH_KILOGRAM_FORCE_PER_METER=10;
  FORCEPERLENGTH_KILOGRAM_FORCE_PER_MILLIMETER=11;
  FORCEPERLENGTH_KILONEWTON_PER_CENTIMETER=12;
  FORCEPERLENGTH_KILONEWTON_PER_METER=13;
  FORCEPERLENGTH_KILONEWTON_PER_MILLIMETER=14;
  FORCEPERLENGTH_KILOPOUND_FORCE_PER_FOOT=15;
  FORCEPERLENGTH_KILOPOUND_FORCE_PER_INCH=16;
  FORCEPERLENGTH_MEGANEWTON_PER_CENTIMETER=17;
  FORCEPERLENGTH_MEGANEWTON_PER_METER=18;
  FORCEPERLENGTH_MEGANEWTON_PER_MILLIMETER=19;
  FORCEPERLENGTH_MICRONEWTON_PER_CENTIMETER=20;
  FORCEPERLENGTH_MICRONEWTON_PER_METER=21;
  FORCEPERLENGTH_MICRONEWTON_PER_MILLIMETER=22;
  FORCEPERLENGTH_MILLINEWTON_PER_CENTIMETER=23;
  FORCEPERLENGTH_MILLINEWTON_PER_METER=24;
  FORCEPERLENGTH_MILLINEWTON_PER_MILLIMETER=25;
  FORCEPERLENGTH_NANONEWTON_PER_CENTIMETER=26;
  FORCEPERLENGTH_NANONEWTON_PER_METER=27;
  FORCEPERLENGTH_NANONEWTON_PER_MILLIMETER=28;
  FORCEPERLENGTH_NEWTON_PER_CENTIMETER=29;
  FORCEPERLENGTH_NEWTON_PER_METER=30;
  FORCEPERLENGTH_NEWTON_PER_MILLIMETER=31;
  FORCEPERLENGTH_POUND_FORCE_PER_FOOT=32;
  FORCEPERLENGTH_POUND_FORCE_PER_INCH=33;
  FORCEPERLENGTH_POUND_FORCE_PER_YARD=34;
  FORCEPERLENGTH_TONNE_FORCE_PER_CENTIMETER=35;
  FORCEPERLENGTH_TONNE_FORCE_PER_METER=36;
  FORCEPERLENGTH_TONNE_FORCE_PER_MILLIMETER=37;
}

//
// Frequency units.
enum FrequencyUnit {
  FREQUENCY_BEAT_PER_MINUTE=0;
  FREQUENCY_CYCLE_PER_HOUR=1;
  FREQUENCY_CYCLE_PER_MINUTE=2;
  FREQUENCY_GIGAHERTZ=3;
  FREQUENCY_HERTZ=4;
  FREQUENCY_KILOHERTZ=5;
  FREQUENCY_MEGAHERTZ=6;
  FREQUENCY_RADIAN_PER_SECOND=7;
  FREQUENCY_TERAHERTZ=8;
}

//
// HeatFlux units.
enum HeatFluxUnit {
  HEATFLUX_BTU_PER_HOUR_SQUARE_FOOT=0;
  HEATFLUX_BTU_PER_MINUTE_SQUARE_FOOT=1;
  HEATFLUX_BTU_PER_SECOND_SQUARE_FOOT=2;
  HEATFLUX_BTU_PER_SECOND_SQUARE_INCH=3;
  HEATFLUX_CALORIE_PER_SECOND_SQUARE_CENTIMETER=4;
  HEATFLUX_CENTIWATT_PER_SQUARE_METER=5;
  HEATFLUX_DECIWATT_PER_SQUARE_METER=6;
  HEATFLUX_KILOCALORIE_PER_HOUR_SQUARE_METER=7;
  HEATFLUX_KILOCALORIE_PER_SECOND_SQUARE_CENTIMETER=8;
  HEATFLUX_KILOWATT_PER_SQUARE_METER=9;
  HEATFLUX_MICROWATT_PER_SQUARE_METER=10;
  HEATFLUX_MILLIWATT_PER_SQUARE_METER=11;
  HEATFLUX_NANOWATT_PER_SQUARE_METER=12;
  HEATFLUX_POUND_FORCE_PER_FOOT_SECOND=13;
  HEATFLUX_POUND_PER_SECOND_CUBED=14;
  HEATFLUX_WATT_PER_SQUARE_FOOT=15;
  HEATFLUX_WATT_PER_SQUARE_INCH=16;
  HEATFLUX_WATT_PER_SQUARE_METER=17;
}

//
// HeatTransferCoefficient units.
enum HeatTransferCoefficientUnit {
  HEATTRANSFERCOEFFICIENT_BTU_PER_SQUARE_FOOT_DEGREE_FAHRENHEIT=0;
  HEATTRANSFERCOEFFICIENT_WATT_PER_SQUARE_METER_CELSIUS=1;
  HEATTRANSFERCOEFFICIENT_WATT_PER_SQUARE_METER_KELVIN=2;
}

//
// InverseArea units.
enum InverseAreaUnit {
  INVERSEAREA_INVERSE_SQUARE_CENTIMETER=0;
  INVERSEAREA_INVERSE_SQUARE_FOOT=1;
  INVERSEAREA_INVERSE_SQUARE_INCH=2;
  INVERSEAREA_INVERSE_SQUARE_METER=3;
  INVERSEAREA_INVERSE_SQUARE_MICROMETER=4;
  INVERSEAREA_INVERSE_SQUARE_MILLIMETER=5;
}

//
// InverseLength units.
enum InverseLengthUnit {
  INVERSELENGTH_INVERSE_CENTIMETER=0;
  INVERSELENGTH_INVERSE_FOOT=1;
  INVERSELENGTH_INVERSE_INCH=2;
  INVERSELENGTH_INVERSE_METER=3;
  INVERSELENGTH_INVERSE_MICROMETER=4;
  INVERSELENGTH_INVERSE_MILLIMETER=5;
}

//
// KinematicViscosity units.
enum KinematicViscosityUnit {
  KINEMATICVISCOSITY_CENTISTOKES=0;
  KINEMATICVISCOSITY_DECISTOKES=1;
  KINEMATICVISCOSITY_KILOSTOKES=2;
  KINEMATICVISCOSITY_MICROSTOKES=3;
  KINEMATICVISCOSITY_MILLISTOKES=4;
  KINEMATICVISCOSITY_NANOSTOKES=5;
  KINEMATICVISCOSITY_SQUARE_METER_PER_SECOND=6;
  KINEMATICVISCOSITY_STOKES=7;
}

//
// Length units.
enum LengthUnit {
  LENGTH_ASTRONOMICAL_UNIT=0;
  LENGTH_CENTIMETER=1;
  LENGTH_DECIMETER=2;
  LENGTH_DTP_PICA=3;
  LENGTH_DTP_POINT=4;
  LENGTH_FATHOM=5;
  LENGTH_FOOT=6;
  LENGTH_HAND=7;
  LENGTH_HECTOMETER=8;
  LENGTH_INCH=9;
  LENGTH_KILOLIGHT_YEAR=10;
  LENGTH_KILOMETER=11;
  LENGTH_KILOPARSEC=12;
  LENGTH_LIGHT_YEAR=13;
  LENGTH_MEGALIGHT_YEAR=14;
  LENGTH_MEGAPARSEC=15;
  LENGTH_METER=16;
  LENGTH_MICROINCH=17;
  LENGTH_MICROMETER=18;
  LENGTH_MIL=19;
  LENGTH_MILE=20;
  LENGTH_MILLIMETER=21;
  LENGTH_NANOMETER=22;
  LENGTH_NAUTICAL_MILE=23;
  LENGTH_PARSEC=24;
  LENGTH_PRINTER_PICA=25;
  LENGTH_PRINTER_POINT=26;
  LENGTH_SHACKLE=27;
  LENGTH_SOLAR_RADIUS=28;
  LENGTH_TWIP=29;
  LENGTH_US_SURVEY_FOOT=30;
  LENGTH_YARD=31;
}

//
// MagneticField units.
enum MagneticFieldUnit {
  MAGNETICFIELD_GAUSS=0;
  MAGNETICFIELD_MICROTESLA=1;
  MAGNETICFIELD_MILLITESLA=2;
  MAGNETICFIELD_NANOTESLA=3;
  MAGNETICFIELD_TESLA=4;
}

//
// Mass units.
enum MassUnit {
  MASS_CENTIGRAM=0;
  MASS_DECAGRAM=1;
  MASS_DECIGRAM=2;
  MASS_EARTH_MASS=3;
  MASS_GRAIN=4;
  MASS_GRAM=5;
  MASS_HECTOGRAM=6;
  MASS_KILOGRAM=7;
  MASS_KILOPOUND=8;
  MASS_KILOTONNE=9;
  MASS_LONG_HUNDREDWEIGHT=10;
  MASS_LONG_TON=11;
  MASS_MEGAPOUND=12;
  MASS_MEGATONNE=13;
  MASS_MICROGRAM=14;
  MASS_MILLIGRAM=15;
  MASS_NANOGRAM=16;
  MASS_OUNCE=17;
  MASS_POUND=18;
  MASS_SHORT_HUNDREDWEIGHT=19;
  MASS_SHORT_TON=20;
  MASS_SLUG=21;
  MASS_SOLAR_MASS=22;
  MASS_STONE=23;
  MASS_TONNE=24;
}

//
// MassConcentration units.
enum MassConcentrationUnit {
  MASSCONCENTRATION_CENTIGRAM_PER_DECILITER=0;
  MASSCONCENTRATION_CENTIGRAM_PER_LITER=1;
  MASSCONCENTRATION_CENTIGRAM_PER_MICROLITER=2;
  MASSCONCENTRATION_CENTIGRAM_PER_MILLILITER=3;
  MASSCONCENTRATION_DECIGRAM_PER_DECILITER=4;
  MASSCONCENTRATION_DECIGRAM_PER_LITER=5;
  MASSCONCENTRATION_DECIGRAM_PER_MICROLITER=6;
  MASSCONCENTRATION_DECIGRAM_PER_MILLILITER=7;
  MASSCONCENTRATION_GRAM_PER_CUBIC_CENTIMETER=8;
  MASSCONCENTRATION_GRAM_PER_CUBIC_METER=9;
  MASSCONCENTRATION_GRAM_PER_CUBIC_MILLIMETER=10;
  MASSCONCENTRATION_GRAM_PER_DECILITER=11;
  MASSCONCENTRATION_GRAM_PER_LITER=12;
  MASSCONCENTRATION_GRAM_PER_MICROLITER=13;
  MASSCONCENTRATION_GRAM_PER_MILLILITER=14;
  MASSCONCENTRATION_KILOGRAM_PER_CUBIC_CENTIMETER=15;
  MASSCONCENTRATION_KILOGRAM_PER_CUBIC_METER=16;
  MASSCONCENTRATION_KILOGRAM_PER_CUBIC_MILLIMETER=17;
  MASSCONCENTRATION_KILOGRAM_PER_LITER=18;
  MASSCONCENTRATION_KILOPOUND_PER_CUBIC_FOOT=19;
  MASSCONCENTRATION_KILOPOUND_PER_CUBIC_INCH=20;
  MASSCONCENTRATION_MICROGRAM_PER_CUBIC_METER=21;
  MASSCONCENTRATION_MICROGRAM_PER_DECILITER=22;
  MASSCONCENTRATION_MICROGRAM_PER_LITER=23;
  MASSCONCENTRATION_MICROGRAM_PER_MICROLITER=24;
  MASSCONCENTRATION_MICROGRAM_PER_MILLILITER=25;
  MASSCONCENTRATION_MILLIGRAM_PER_CUBIC_METER=26;
  MASSCONCENTRATION_MILLIGRAM_PER_DECILITER=27;
  MASSCONCENTRATION_MILLIGRAM_PER_LITER=28;
  MASSCONCENTRATION_MILLIGRAM_PER_MICROLITER=29;
  MASSCONCENTRATION_MILLIGRAM_PER_MILLILITER=30;
  MASSCONCENTRATION_NANOGRAM_PER_DECILITER=31;
  MASSCONCENTRATION_NANOGRAM_PER_LITER=32;
  MASSCONCENTRATION_NANOGRAM_PER_MICROLITER=33;
  MASSCONCENTRATION_NANOGRAM_PER_MILLILITER=34;
  MASSCONCENTRATION_PICOGRAM_PER_DECILITER=35;
  MASSCONCENTRATION_PICOGRAM_PER_LITER=36;
  MASSCONCENTRATION_PICOGRAM_PER_MICROLITER=37;
  MASSCONCENTRATION_PICOGRAM_PER_MILLILITER=38;
  MASSCONCENTRATION_POUND_PER_CUBIC_FOOT=39;
  MASSCONCENTRATION_POUND_PER_CUBIC_INCH=40;
  MASSCONCENTRATION_POUND_PER_IMPERIAL_GALLON=41;
  MASSCONCENTRATION_POUND_PER_U_S_GALLON=42;
  MASSCONCENTRATION_SLUG_PER_CUBIC_FOOT=43;
  MASSCONCENTRATION_TONNE_PER_CUBIC_CENTIMETER=44;
  MASSCONCENTRATION_TONNE_PER_CUBIC_METER=45;
  MASSCONCENTRATION_TONNE_PER_CUBIC_MILLIMETER=46;
}

//
// MassFlow units.
enum MassFlowUnit {
  MASSFLOW_CENTIGRAM_PER_DAY=0;
  MASSFLOW_CENTIGRAM_PER_SECOND=1;
  MASSFLOW_DECAGRAM_PER_DAY=2;
  MASSFLOW_DECAGRAM_PER_SECOND=3;
  MASSFLOW_DECIGRAM_PER_DAY=4;
  MASSFLOW_DECIGRAM_PER_SECOND=5;
  MASSFLOW_GRAM_PER_DAY=6;
  MASSFLOW_GRAM_PER_HOUR=7;
  MASSFLOW_GRAM_PER_SECOND=8;
  MASSFLOW_HECTOGRAM_PER_DAY=9;
  MASSFLOW_HECTOGRAM_PER_SECOND=10;
  MASSFLOW_KILOGRAM_PER_DAY=11;
  MASSFLOW_KILOGRAM_PER_HOUR=12;
  MASSFLOW_KILOGRAM_PER_MINUTE=13;
  MASSFLOW_KILOGRAM_PER_SECOND=14;
  MASSFLOW_MEGAGRAM_PER_DAY=15;
  MASSFLOW_MEGAPOUND_PER_DAY=16;
  MASSFLOW_MEGAPOUND_PER_HOUR=17;
  MASSFLOW_MEGAPOUND_PER_MINUTE=18;
  MASSFLOW_MEGAPOUND_PER_SECOND=19;
  MASSFLOW_MICROGRAM_PER_DAY=20;
  MASSFLOW_MICROGRAM_PER_SECOND=21;
  MASSFLOW_MILLIGRAM_PER_DAY=22;
  MASSFLOW_MILLIGRAM_PER_SECOND=23;
  MASSFLOW_NANOGRAM_PER_DAY=24;
  MASSFLOW_NANOGRAM_PER_SECOND=25;
  MASSFLOW_POUND_PER_DAY=26;
  MASSFLOW_POUND_PER_HOUR=27;
  MASSFLOW_POUND_PER_MINUTE=28;
  MASSFLOW_POUND_PER_SECOND=29;
  MASSFLOW_SHORT_TON_PER_HOUR=30;
  MASSFLOW_TONNE_PER_DAY=31;
  MASSFLOW_TONNE_PER_HOUR=32;
}

//
// MassFlux units.
enum MassFluxUnit {
  MASSFLUX_GRAM_PER_HOUR_PER_SQUARE_CENTIMETER=0;
  MASSFLUX_GRAM_PER_HOUR_PER_SQUARE_METER=1;
  MASSFLUX_GRAM_PER_HOUR_PER_SQUARE_MILLIMETER=2;
  MASSFLUX_GRAM_PER_SECOND_PER_SQUARE_CENTIMETER=3;
  MASSFLUX_GRAM_PER_SECOND_PER_SQUARE_METER=4;
  MASSFLUX_GRAM_PER_SECOND_PER_SQUARE_MILLIMETER=5;
  MASSFLUX_KILOGRAM_PER_HOUR_PER_SQUARE_CENTIMETER=6;
  MASSFLUX_KILOGRAM_PER_HOUR_PER_SQUARE_METER=7;
  MASSFLUX_KILOGRAM_PER_HOUR_PER_SQUARE_MILLIMETER=8;
  MASSFLUX_KILOGRAM_PER_SECOND_PER_SQUARE_CENTIMETER=9;
  MASSFLUX_KILOGRAM_PER_SECOND_PER_SQUARE_METER=10;
  MASSFLUX_KILOGRAM_PER_SECOND_PER_SQUARE_MILLIMETER=11;
}

//
// MassFraction units.
enum MassFractionUnit {
  MASSFRACTION_CENTIGRAM_PER_GRAM=0;
  MASSFRACTION_CENTIGRAM_PER_KILOGRAM=1;
  MASSFRACTION_DECAGRAM_PER_GRAM=2;
  MASSFRACTION_DECAGRAM_PER_KILOGRAM=3;
  MASSFRACTION_DECIGRAM_PER_GRAM=4;
  MASSFRACTION_DECIGRAM_PER_KILOGRAM=5;
  MASSFRACTION_DECIMAL_FRACTION=6;
  MASSFRACTION_GRAM_PER_GRAM=7;
  MASSFRACTION_GRAM_PER_KILOGRAM=8;
  MASSFRACTION_HECTOGRAM_PER_GRAM=9;
  MASSFRACTION_HECTOGRAM_PER_KILOGRAM=10;
  MASSFRACTION_KILOGRAM_PER_GRAM=11;
  MASSFRACTION_KILOGRAM_PER_KILOGRAM=12;
  MASSFRACTION_MICROGRAM_PER_GRAM=13;
  MASSFRACTION_MICROGRAM_PER_KILOGRAM=14;
  MASSFRACTION_MILLIGRAM_PER_GRAM=15;
  MASSFRACTION_MILLIGRAM_PER_KILOGRAM=16;
  MASSFRACTION_NANOGRAM_PER_GRAM=17;
  MASSFRACTION_NANOGRAM_PER_KILOGRAM=18;
  MASSFRACTION_PART_PER_BILLION=19;
  MASSFRACTION_PART_PER_MILLION=20;
  MASSFRACTION_PART_PER_THOUSAND=21;
  MASSFRACTION_PART_PER_TRILLION=22;
  MASSFRACTION_PERCENT=23;
}

//
// MassMomentOfInertia units.
enum MassMomentOfInertiaUnit {
  MASSMOMENTOFINERTIA_GRAM_SQUARE_CENTIMETER=0;
  MASSMOMENTOFINERTIA_GRAM_SQUARE_DECIMETER=1;
  MASSMOMENTOFINERTIA_GRAM_SQUARE_METER=2;
  MASSMOMENTOFINERTIA_GRAM_SQUARE_MILLIMETER=3;
  MASSMOMENTOFINERTIA_KILOGRAM_SQUARE_CENTIMETER=4;
  MASSMOMENTOFINERTIA_KILOGRAM_SQUARE_DECIMETER=5;
  MASSMOMENTOFINERTIA_KILOGRAM_SQUARE_METER=6;
  MASSMOMENTOFINERTIA_KILOGRAM_SQUARE_MILLIMETER=7;
  MASSMOMENTOFINERTIA_KILOTONNE_SQUARE_CENTIMETER=8;
  MASSMOMENTOFINERTIA_KILOTONNE_SQUARE_DECIMETER=9;
  MASSMOMENTOFINERTIA_KILOTONNE_SQUARE_METER=10;
  MASSMOMENTOFINERTIA_KILOTONNE_SQUARE_MILIMETER=11;
  MASSMOMENTOFINERTIA_MEGATONNE_SQUARE_CENTIMETER=12;
  MASSMOMENTOFINERTIA_MEGATONNE_SQUARE_DECIMETER=13;
  MASSMOMENTOFINERTIA_MEGATONNE_SQUARE_METER=14;
  MASSMOMENTOFINERTIA_MEGATONNE_SQUARE_MILIMETER=15;
  MASSMOMENTOFINERTIA_MILLIGRAM_SQUARE_CENTIMETER=16;
  MASSMOMENTOFINERTIA_MILLIGRAM_SQUARE_DECIMETER=17;
  MASSMOMENTOFINERTIA_MILLIGRAM_SQUARE_METER=18;
  MASSMOMENTOFINERTIA_MILLIGRAM_SQUARE_MILLIMETER=19;
  MASSMOMENTOFINERTIA_POUND_SQUARE_FOOT=20;
  MASSMOMENTOFINERTIA_POUND_SQUARE_INCH=21;
  MASSMOMENTOFINERTIA_SLUG_SQUARE_FOOT=22;
  MASSMOMENTOFINERTIA_SLUG_SQUARE_INCH=23;
  MASSMOMENTOFINERTIA_TONNE_SQUARE_CENTIMETER=24;
  MASSMOMENTOFINERTIA_TONNE_SQUARE_DECIMETER=25;
  MASSMOMENTOFINERTIA_TONNE_SQUARE_METER=26;
  MASSMOMENTOFINERTIA_TONNE_SQUARE_MILIMETER=27;
}

//
// Molarity units.
enum MolarityUnit {
  MOLARITY_CENTIMOLES_PER_LITER=0;
  MOLARITY_DECIMOLES_PER_LITER=1;
  MOLARITY_MICROMOLES_PER_LITER=2;
  MOLARITY_MILLIMOLES_PER_LITER=3;
  MOLARITY_MOLES_PER_CUBIC_METER=4;
  MOLARITY_MOLES_PER_LITER=5;
  MOLARITY_NANOMOLES_PER_LITER=6;
  MOLARITY_PICOMOLES_PER_LITER=7;
}

//
// MolarMass units.
enum MolarMassUnit {
  MOLARMASS_CENTIGRAM_PER_MOLE=0;
  MOLARMASS_DECAGRAM_PER_MOLE=1;
  MOLARMASS_DECIGRAM_PER_MOLE=2;
  MOLARMASS_GRAM_PER_MOLE=3;
  MOLARMASS_HECTOGRAM_PER_MOLE=4;
  MOLARMASS_KILOGRAM_PER_MOLE=5;
  MOLARMASS_KILOPOUND_PER_MOLE=6;
  MOLARMASS_MEGAPOUND_PER_MOLE=7;
  MOLARMASS_MICROGRAM_PER_MOLE=8;
  MOLARMASS_MILLIGRAM_PER_MOLE=9;
  MOLARMASS_NANOGRAM_PER_MOLE=10;
  MOLARMASS_POUND_PER_MOLE=11;
}

//
// Permeability units.
enum PermeabilityUnit {
  PERMEABILITY_HENRY_PER_METER=0;
}

//
// Permittivity units.
enum PermittivityUnit {
  PERMITTIVITY_FARAD_PER_METER=0;
}

//
// Power units.
enum PowerUnit {
  POWER_BOILER_HORSEPOWER=0;
  POWER_BRITISH_THERMAL_UNIT_PER_HOUR=1;
  POWER_DECAWATT=2;
  POWER_DECIWATT=3;
  POWER_ELECTRICAL_HORSEPOWER=4;
  POWER_FEMTOWATT=5;
  POWER_GIGAJOULE_PER_HOUR=6;
  POWER_GIGAWATT=7;
  POWER_HYDRAULIC_HORSEPOWER=8;
  POWER_JOULE_PER_HOUR=9;
  POWER_KILOBRITISH_THERMAL_UNIT_PER_HOUR=10;
  POWER_KILOJOULE_PER_HOUR=11;
  POWER_KILOWATT=12;
  POWER_MECHANICAL_HORSEPOWER=13;
  POWER_MEGAJOULE_PER_HOUR=14;
  POWER_MEGAWATT=15;
  POWER_METRIC_HORSEPOWER=16;
  POWER_MICROWATT=17;
  POWER_MILLIJOULE_PER_HOUR=18;
  POWER_MILLIWATT=19;
  POWER_NANOWATT=20;
  POWER_PETAWATT=21;
  POWER_PICOWATT=22;
  POWER_TERAWATT=23;
  POWER_WATT=24;
}

//
// PowerDensity units.
enum PowerDensityUnit {
  POWERDENSITY_DECAWATT_PER_CUBIC_FOOT=0;
  POWERDENSITY_DECAWATT_PER_CUBIC_INCH=1;
  POWERDENSITY_DECAWATT_PER_CUBIC_METER=2;
  POWERDENSITY_DECAWATT_PER_LITER=3;
  POWERDENSITY_DECIWATT_PER_CUBIC_FOOT=4;
  POWERDENSITY_DECIWATT_PER_CUBIC_INCH=5;
  POWERDENSITY_DECIWATT_PER_CUBIC_METER=6;
  POWERDENSITY_DECIWATT_PER_LITER=7;
  POWERDENSITY_GIGAWATT_PER_CUBIC_FOOT=8;
  POWERDENSITY_GIGAWATT_PER_CUBIC_INCH=9;
  POWERDENSITY_GIGAWATT_PER_CUBIC_METER=10;
  POWERDENSITY_GIGAWATT_PER_LITER=11;
  POWERDENSITY_KILOWATT_PER_CUBIC_FOOT=12;
  POWERDENSITY_KILOWATT_PER_CUBIC_INCH=13;
  POWERDENSITY_KILOWATT_PER_CUBIC_METER=14;
  POWERDENSITY_KILOWATT_PER_LITER=15;
  POWERDENSITY_MEGAWATT_PER_CUBIC_FOOT=16;
  POWERDENSITY_MEGAWATT_PER_CUBIC_INCH=17;
  POWERDENSITY_MEGAWATT_PER_CUBIC_METER=18;
  POWERDENSITY_MEGAWATT_PER_LITER=19;
  POWERDENSITY_MICROWATT_PER_CUBIC_FOOT=20;
  POWERDENSITY_MICROWATT_PER_CUBIC_INCH=21;
  POWERDENSITY_MICROWATT_PER_CUBIC_METER=22;
  POWERDENSITY_MICROWATT_PER_LITER=23;
  POWERDENSITY_MILLIWATT_PER_CUBIC_FOOT=24;
  POWERDENSITY_MILLIWATT_PER_CUBIC_INCH=25;
  POWERDENSITY_MILLIWATT_PER_CUBIC_METER=26;
  POWERDENSITY_MILLIWATT_PER_LITER=27;
  POWERDENSITY_NANOWATT_PER_CUBIC_FOOT=28;
  POWERDENSITY_NANOWATT_PER_CUBIC_INCH=29;
  POWERDENSITY_NANOWATT_PER_CUBIC_METER=30;
  POWERDENSITY_NANOWATT_PER_LITER=31;
  POWERDENSITY_PICOWATT_PER_CUBIC_FOOT=32;
  POWERDENSITY_PICOWATT_PER_CUBIC_INCH=33;
  POWERDENSITY_PICOWATT_PER_CUBIC_METER=34;
  POWERDENSITY_PICOWATT_PER_LITER=35;
  POWERDENSITY_TERAWATT_PER_CUBIC_FOOT=36;
  POWERDENSITY_TERAWATT_PER_CUBIC_INCH=37;
  POWERDENSITY_TERAWATT_PER_CUBIC_METER=38;
  POWERDENSITY_TERAWATT_PER_LITER=39;
  POWERDENSITY_WATT_PER_CUBIC_FOOT=40;
  POWERDENSITY_WATT_PER_CUBIC_INCH=41;
  POWERDENSITY_WATT_PER_CUBIC_METER=42;
  POWERDENSITY_WATT_PER_LITER=43;
}

//
// PowerRatio units.
enum PowerRatioUnit {
  POWERRATIO_DECIBEL_MILLIWATT=0;
  POWERRATIO_DECIBEL_WATT=1;
}

//
// Pressure units.
enum PressureUnit {
  PRESSURE_ATMOSPHERE=0;
  PRESSURE_BAR=1;
  PRESSURE_CENTIBAR=2;
  PRESSURE_DECAPASCAL=3;
  PRESSURE_DECIBAR=4;
  PRESSURE_DYNE_PER_SQUARE_CENTIMETER=5;
  PRESSURE_FOOT_OF_HEAD=6;
  PRESSURE_GIGAPASCAL=7;
  PRESSURE_HECTOPASCAL=8;
  PRESSURE_INCH_OF_MERCURY=9;
  PRESSURE_INCH_OF_WATER_COLUMN=10;
  PRESSURE_KILOBAR=11;
  PRESSURE_KILOGRAM_FORCE_PER_SQUARE_CENTIMETER=12;
  PRESSURE_KILOGRAM_FORCE_PER_SQUARE_METER=13;
  PRESSURE_KILOGRAM_FORCE_PER_SQUARE_MILLIMETER=14;
  PRESSURE_KILONEWTON_PER_SQUARE_CENTIMETER=15;
  PRESSURE_KILONEWTON_PER_SQUARE_METER=16;
  PRESSURE_KILONEWTON_PER_SQUARE_MILLIMETER=17;
  PRESSURE_KILOPASCAL=18;
  PRESSURE_KILOPOUND_FORCE_PER_SQUARE_FOOT=19;
  PRESSURE_KILOPOUND_FORCE_PER_SQUARE_INCH=20;
  PRESSURE_MEGABAR=21;
  PRESSURE_MEGANEWTON_PER_SQUARE_METER=22;
  PRESSURE_MEGAPASCAL=23;
  PRESSURE_METER_OF_HEAD=24;
  PRESSURE_MICROBAR=25;
  PRESSURE_MICROPASCAL=26;
  PRESSURE_MILLIBAR=27;
  PRESSURE_MILLIMETER_OF_MERCURY=28;
  PRESSURE_MILLIPASCAL=29;
  PRESSURE_NEWTON_PER_SQUARE_CENTIMETER=30;
  PRESSURE_NEWTON_PER_SQUARE_METER=31;
  PRESSURE_NEWTON_PER_SQUARE_MILLIMETER=32;
  PRESSURE_PASCAL=33;
  PRESSURE_POUND_FORCE_PER_SQUARE_FOOT=34;
  PRESSURE_POUND_FORCE_PER_SQUARE_INCH=35;
  PRESSURE_POUND_PER_INCH_SECOND_SQUARED=36;
  PRESSURE_TECHNICAL_ATMOSPHERE=37;
  PRESSURE_TONNE_FORCE_PER_SQUARE_CENTIMETER=38;
  PRESSURE_TONNE_FORCE_PER_SQUARE_METER=39;
  PRESSURE_TONNE_FORCE_PER_SQUARE_MILLIMETER=40;
  PRESSURE_TORR=41;
}

//
// Ratio units.
enum RatioUnit {
  RATIO_DECIMAL_FRACTION=0;
  RATIO_PART_PER_BILLION=1;
  RATIO_PART_PER_MILLION=2;
  RATIO_PART_PER_THOUSAND=3;
  RATIO_PART_PER_TRILLION=4;
  RATIO_PERCENT=5;
}

//
// RatioChangeRate units.
enum RatioChangeRateUnit {
  RATIOCHANGERATE_DECIMAL_FRACTION_PER_SECOND=0;
  RATIOCHANGERATE_PERCENT_PER_SECOND=1;
}

//
// ReactiveEnergy units.
enum ReactiveEnergyUnit {
  REACTIVEENERGY_KILOVOLTAMPERE_REACTIVE_HOUR=0;
  REACTIVEENERGY_MEGAVOLTAMPERE_REACTIVE_HOUR=1;
  REACTIVEENERGY_VOLTAMPERE_REACTIVE_HOUR=2;
}

//
// ReactivePower units.
enum ReactivePowerUnit {
  REACTIVEPOWER_GIGAVOLTAMPERE_REACTIVE=0;
  REACTIVEPOWER_KILOVOLTAMPERE_REACTIVE=1;
  REACTIVEPOWER_MEGAVOLTAMPERE_REACTIVE=2;
  REACTIVEPOWER_VOLTAMPERE_REACTIVE=3;
}

//
// RotationalAcceleration units.
enum RotationalAccelerationUnit {
  ROTATIONALACCELERATION_DEGREE_PER_SECOND_SQUARED=0;
  ROTATIONALACCELERATION_RADIAN_PER_SECOND_SQUARED=1;
  ROTATIONALACCELERATION_REVOLUTION_PER_MINUTE_PER_SECOND=2;
  ROTATIONALACCELERATION_REVOLUTION_PER_SECOND_SQUARED=3;
}

//
// RotationalSpeed units.
enum RotationalSpeedUnit {
  ROTATIONALSPEED_CENTIRADIAN_PER_SECOND=0;
  ROTATIONALSPEED_DECIRADIAN_PER_SECOND=1;
  ROTATIONALSPEED_DEGREE_PER_MINUTE=2;
  ROTATIONALSPEED_DEGREE_PER_SECOND=3;
  ROTATIONALSPEED_MICRODEGREE_PER_SECOND=4;
  ROTATIONALSPEED_MICRORADIAN_PER_SECOND=5;
  ROTATIONALSPEED_MILLIDEGREE_PER_SECOND=6;
  ROTATIONALSPEED_MILLIRADIAN_PER_SECOND=7;
  ROTATIONALSPEED_NANODEGREE_PER_SECOND=8;
  ROTATIONALSPEED_NANORADIAN_PER_SECOND=9;
  ROTATIONALSPEED_RADIAN_PER_SECOND=10;
  ROTATIONALSPEED_REVOLUTION_PER_MINUTE=11;
  ROTATIONALSPEED_REVOLUTION_PER_SECOND=12;
}

//
// RotationalStiffness units.
enum RotationalStiffnessUnit {
  ROTATIONALSTIFFNESS_CENTINEWTON_METER_PER_DEGREE=0;
  ROTATIONALSTIFFNESS_CENTINEWTON_MILLIMETER_PER_DEGREE=1;
  ROTATIONALSTIFFNESS_CENTINEWTON_MILLIMETER_PER_RADIAN=2;
  ROTATIONALSTIFFNESS_DECANEWTON_METER_PER_DEGREE=3;
  ROTATIONALSTIFFNESS_DECANEWTON_MILLIMETER_PER_DEGREE=4;
  ROTATIONALSTIFFNESS_DECANEWTON_MILLIMETER_PER_RADIAN=5;
  ROTATIONALSTIFFNESS_DECINEWTON_METER_PER_DEGREE=6;
  ROTATIONALSTIFFNESS_DECINEWTON_MILLIMETER_PER_DEGREE=7;
  ROTATIONALSTIFFNESS_DECINEWTON_MILLIMETER_PER_RADIAN=8;
  ROTATIONALSTIFFNESS_KILONEWTON_METER_PER_DEGREE=9;
  ROTATIONALSTIFFNESS_KILONEWTON_METER_PER_RADIAN=10;
  ROTATIONALSTIFFNESS_KILONEWTON_MILLIMETER_PER_DEGREE=11;
  ROTATIONALSTIFFNESS_KILONEWTON_MILLIMETER_PER_RADIAN=12;
  ROTATIONALSTIFFNESS_KILOPOUND_FORCE_FOOT_PER_DEGREES=13;
  ROTATIONALSTIFFNESS_MEGANEWTON_METER_PER_DEGREE=14;
  ROTATIONALSTIFFNESS_MEGANEWTON_METER_PER_RADIAN=15;
  ROTATIONALSTIFFNESS_MEGANEWTON_MILLIMETER_PER_DEGREE=16;
  ROTATIONALSTIFFNESS_MEGANEWTON_MILLIMETER_PER_RADIAN=17;
  ROTATIONALSTIFFNESS_MICRONEWTON_METER_PER_DEGREE=18;
  ROTATIONALSTIFFNESS_MICRONEWTON_MILLIMETER_PER_DEGREE=19;
  ROTATIONALSTIFFNESS_MICRONEWTON_MILLIMETER_PER_RADIAN=20;
  ROTATIONALSTIFFNESS_MILLINEWTON_METER_PER_DEGREE=21;
  ROTATIONALSTIFFNESS_MILLINEWTON_MILLIMETER_PER_DEGREE=22;
  ROTATIONALSTIFFNESS_MILLINEWTON_MILLIMETER_PER_RADIAN=23;
  ROTATIONALSTIFFNESS_NANONEWTON_METER_PER_DEGREE=24;
  ROTATIONALSTIFFNESS_NANONEWTON_MILLIMETER_PER_DEGREE=25;
  ROTATIONALSTIFFNESS_NANONEWTON_MILLIMETER_PER_RADIAN=26;
  ROTATIONALSTIFFNESS_NEWTON_METER_PER_DEGREE=27;
  ROTATIONALSTIFFNESS_NEWTON_METER_PER_RADIAN=28;
  ROTATIONALSTIFFNESS_NEWTON_MILLIMETER_PER_DEGREE=29;
  ROTATIONALSTIFFNESS_NEWTON_MILLIMETER_PER_RADIAN=30;
  ROTATIONALSTIFFNESS_POUND_FORCE_FEET_PER_RADIAN=31;
  ROTATIONALSTIFFNESS_POUND_FORCE_FOOT_PER_DEGREES=32;
}

//
// RotationalStiffnessPerLength units.
enum RotationalStiffnessPerLengthUnit {
  ROTATIONALSTIFFNESSPERLENGTH_KILONEWTON_METER_PER_RADIAN_PER_METER=0;
  ROTATIONALSTIFFNESSPERLENGTH_KILOPOUND_FORCE_FOOT_PER_DEGREES_PER_FOOT=1;
  ROTATIONALSTIFFNESSPERLENGTH_MEGANEWTON_METER_PER_RADIAN_PER_METER=2;
  ROTATIONALSTIFFNESSPERLENGTH_NEWTON_METER_PER_RADIAN_PER_METER=3;
  ROTATIONALSTIFFNESSPERLENGTH_POUND_FORCE_FOOT_PER_DEGREES_PER_FOOT=4;
}

//
// SolidAngle units.
enum SolidAngleUnit {
  SOLIDANGLE_STERADIAN=0;
}

//
// SpecificEnergy units.
enum SpecificEnergyUnit {
  SPECIFICENERGY_BTU_PER_POUND=0;
  SPECIFICENERGY_CALORIE_PER_GRAM=1;
  SPECIFICENERGY_GIGAWATT_DAY_PER_KILOGRAM=2;
  SPECIFICENERGY_GIGAWATT_DAY_PER_SHORT_TON=3;
  SPECIFICENERGY_GIGAWATT_DAY_PER_TONNE=4;
  SPECIFICENERGY_GIGAWATT_HOUR_PER_KILOGRAM=5;
  SPECIFICENERGY_JOULE_PER_KILOGRAM=6;
  SPECIFICENERGY_KILOCALORIE_PER_GRAM=7;
  SPECIFICENERGY_KILOJOULE_PER_KILOGRAM=8;
  SPECIFICENERGY_KILOWATT_DAY_PER_KILOGRAM=9;
  SPECIFICENERGY_KILOWATT_DAY_PER_SHORT_TON=10;
  SPECIFICENERGY_KILOWATT_DAY_PER_TONNE=11;
  SPECIFICENERGY_KILOWATT_HOUR_PER_KILOGRAM=12;
  SPECIFICENERGY_MEGAJOULE_PER_KILOGRAM=13;
  SPECIFICENERGY_MEGAWATT_DAY_PER_KILOGRAM=14;
  SPECIFICENERGY_MEGAWATT_DAY_PER_SHORT_TON=15;
  SPECIFICENERGY_MEGAWATT_DAY_PER_TONNE=16;
  SPECIFICENERGY_MEGAWATT_HOUR_PER_KILOGRAM=17;
  SPECIFICENERGY_TERAWATT_DAY_PER_KILOGRAM=18;
  SPECIFICENERGY_TERAWATT_DAY_PER_SHORT_TON=19;
  SPECIFICENERGY_TERAWATT_DAY_PER_TONNE=20;
  SPECIFICENERGY_WATT_DAY_PER_KILOGRAM=21;
  SPECIFICENERGY_WATT_DAY_PER_SHORT_TON=22;
  SPECIFICENERGY_WATT_DAY_PER_TONNE=23;
  SPECIFICENERGY_WATT_HOUR_PER_KILOGRAM=24;
}

//
// SpecificEntropy units.
enum SpecificEntropyUnit {
  SPECIFICENTROPY_BTU_PER_POUND_FAHRENHEIT=0;
  SPECIFICENTROPY_CALORIE_PER_GRAM_KELVIN=1;
  SPECIFICENTROPY_JOULE_PER_KILOGRAM_DEGREE_CELSIUS=2;
  SPECIFICENTROPY_JOULE_PER_KILOGRAM_KELVIN=3;
  SPECIFICENTROPY_KILOCALORIE_PER_GRAM_KELVIN=4;
  SPECIFICENTROPY_KILOJOULE_PER_KILOGRAM_DEGREE_CELSIUS=5;
  SPECIFICENTROPY_KILOJOULE_PER_KILOGRAM_KELVIN=6;
  SPECIFICENTROPY_MEGAJOULE_PER_KILOGRAM_DEGREE_CELSIUS=7;
  SPECIFICENTROPY_MEGAJOULE_PER_KILOGRAM_KELVIN=8;
}

//
// SpecificVolume units.
enum SpecificVolumeUnit {
  SPECIFICVOLUME_CUBIC_FOOT_PER_POUND=0;
  SPECIFICVOLUME_CUBIC_METER_PER_KILOGRAM=1;
  SPECIFICVOLUME_MILLICUBIC_METER_PER_KILOGRAM=2;
}

//
// SpecificWeight units.
enum SpecificWeightUnit {
  SPECIFICWEIGHT_KILOGRAM_FORCE_PER_CUBIC_CENTIMETER=0;
  SPECIFICWEIGHT_KILOGRAM_FORCE_PER_CUBIC_METER=1;
  SPECIFICWEIGHT_KILOGRAM_FORCE_PER_CUBIC_MILLIMETER=2;
  SPECIFICWEIGHT_KILONEWTON_PER_CUBIC_CENTIMETER=3;
  SPECIFICWEIGHT_KILONEWTON_PER_CUBIC_METER=4;
  SPECIFICWEIGHT_KILONEWTON_PER_CUBIC_MILLIMETER=5;
  SPECIFICWEIGHT_KILOPOUND_FORCE_PER_CUBIC_FOOT=6;
  SPECIFICWEIGHT_KILOPOUND_FORCE_PER_CUBIC_INCH=7;
  SPECIFICWEIGHT_MEGANEWTON_PER_CUBIC_METER=8;
  SPECIFICWEIGHT_NEWTON_PER_CUBIC_CENTIMETER=9;
  SPECIFICWEIGHT_NEWTON_PER_CUBIC_METER=10;
  SPECIFICWEIGHT_NEWTON_PER_CUBIC_MILLIMETER=11;
  SPECIFICWEIGHT_POUND_FORCE_PER_CUBIC_FOOT=12;
  SPECIFICWEIGHT_POUND_FORCE_PER_CUBIC_INCH=13;
  SPECIFICWEIGHT_TONNE_FORCE_PER_CUBIC_CENTIMETER=14;
  SPECIFICWEIGHT_TONNE_FORCE_PER_CUBIC_METER=15;
  SPECIFICWEIGHT_TONNE_FORCE_PER_CUBIC_MILLIMETER=16;
}

//
// Speed units.
enum SpeedUnit {
  SPEED_CENTIMETER_PER_HOUR=0;
  SPEED_CENTIMETER_PER_MINUTE=1;
  SPEED_CENTIMETER_PER_SECOND=2;
  SPEED_DECIMETER_PER_MINUTE=3;
  SPEED_DECIMETER_PER_SECOND=4;
  SPEED_FOOT_PER_HOUR=5;
  SPEED_FOOT_PER_MINUTE=6;
  SPEED_FOOT_PER_SECOND=7;
  SPEED_INCH_PER_HOUR=8;
  SPEED_INCH_PER_MINUTE=9;
  SPEED_INCH_PER_SECOND=10;
  SPEED_KILOMETER_PER_HOUR=11;
  SPEED_KILOMETER_PER_MINUTE=12;
  SPEED_KILOMETER_PER_SECOND=13;
  SPEED_KNOT=14;
  SPEED_METER_PER_HOUR=15;
  SPEED_METER_PER_MINUTE=16;
  SPEED_METER_PER_SECOND=17;
  SPEED_MICROMETER_PER_MINUTE=18;
  SPEED_MICROMETER_PER_SECOND=19;
  SPEED_MILE_PER_HOUR=20;
  SPEED_MILLIMETER_PER_HOUR=21;
  SPEED_MILLIMETER_PER_MINUTE=22;
  SPEED_MILLIMETER_PER_SECOND=23;
  SPEED_NANOMETER_PER_MINUTE=24;
  SPEED_NANOMETER_PER_SECOND=25;
  SPEED_US_SURVEY_FOOT_PER_HOUR=26;
  SPEED_US_SURVEY_FOOT_PER_MINUTE=27;
  SPEED_US_SURVEY_FOOT_PER_SECOND=28;
  SPEED_YARD_PER_HOUR=29;
  SPEED_YARD_PER_MINUTE=30;
  SPEED_YARD_PER_SECOND=31;
}

//
// Temperature units.
enum TemperatureUnit {
  TEMPERATURE_DEGREE_CELSIUS=0;
  TEMPERATURE_DEGREE_DELISLE=1;
  TEMPERATURE_DEGREE_FAHRENHEIT=2;
  TEMPERATURE_DEGREE_NEWTON=3;
  TEMPERATURE_DEGREE_RANKINE=4;
  TEMPERATURE_DEGREE_REAUMUR=5;
  TEMPERATURE_DEGREE_ROEMER=6;
  TEMPERATURE_KELVIN=7;
  TEMPERATURE_SOLAR_TEMPERATURE=8;
}

//
// TemperatureChangeRate units.
enum TemperatureChangeRateUnit {
  TEMPERATURECHANGERATE_CENTIDEGREE_CELSIUS_PER_SECOND=0;
  TEMPERATURECHANGERATE_DECADEGREE_CELSIUS_PER_SECOND=1;
  TEMPERATURECHANGERATE_DECIDEGREE_CELSIUS_PER_SECOND=2;
  TEMPERATURECHANGERATE_DEGREE_CELSIUS_PER_MINUTE=3;
  TEMPERATURECHANGERATE_DEGREE_CELSIUS_PER_SECOND=4;
  TEMPERATURECHANGERATE_HECTODEGREE_CELSIUS_PER_SECOND=5;
  TEMPERATURECHANGERATE_KILODEGREE_CELSIUS_PER_SECOND=6;
  TEMPERATURECHANGERATE_MICRODEGREE_CELSIUS_PER_SECOND=7;
  TEMPERATURECHANGERATE_MILLIDEGREE_CELSIUS_PER_SECOND=8;
  TEMPERATURECHANGERATE_NANODEGREE_CELSIUS_PER_SECOND=9;
}

//
// TemperatureDelta units.
enum TemperatureDeltaUnit {
  TEMPERATUREDELTA_DEGREE_CELSIUS=0;
  TEMPERATUREDELTA_DEGREE_DELISLE=1;
  TEMPERATUREDELTA_DEGREE_FAHRENHEIT=2;
  TEMPERATUREDELTA_DEGREE_NEWTON=3;
  TEMPERATUREDELTA_DEGREE_RANKINE=4;
  TEMPERATUREDELTA_DEGREE_REAUMUR=5;
  TEMPERATUREDELTA_DEGREE_ROEMER=6;
  TEMPERATUREDELTA_KELVIN=7;
  TEMPERATUREDELTA_MILLIDEGREE_CELSIUS=8;
}

//
// ThermalConductivity units.
enum ThermalConductivityUnit {
  THERMALCONDUCTIVITY_BTU_PER_HOUR_FOOT_FAHRENHEIT=0;
  THERMALCONDUCTIVITY_WATT_PER_METER_KELVIN=1;
}

//
// ThermalResistance units.
enum ThermalResistanceUnit {
  THERMALRESISTANCE_HOUR_SQUARE_FEET_DEGREE_FAHRENHEIT_PER_BTU=0;
  THERMALRESISTANCE_SQUARE_CENTIMETER_HOUR_DEGREE_CELSIUS_PER_KILOCALORIE=1;
  THERMALRESISTANCE_SQUARE_CENTIMETER_KELVIN_PER_WATT=2;
  THERMALRESISTANCE_SQUARE_METER_DEGREE_CELSIUS_PER_WATT=3;
  THERMALRESISTANCE_SQUARE_METER_KELVIN_PER_KILOWATT=4;
}

//
// Time units.
enum TimeUnit {
  TIME_DAY=0;
  TIME_HOUR=1;
  TIME_MICROSECOND=2;
  TIME_MILLISECOND=3;
  TIME_MINUTE=4;
  TIME_MONTH=5;
  TIME_NANOSECOND=6;
  TIME_SECOND=7;
  TIME_WEEK=8;
  TIME_YEAR=9;
}

//
// Torque units.
enum TorqueUnit {
  TORQUE_KILOGRAM_FORCE_CENTIMETER=0;
  TORQUE_KILOGRAM_FORCE_METER=1;
  TORQUE_KILOGRAM_FORCE_MILLIMETER=2;
  TORQUE_KILONEWTON_CENTIMETER=3;
  TORQUE_KILONEWTON_METER=4;
  TORQUE_KILONEWTON_MILLIMETER=5;
  TORQUE_KILOPOUND_FORCE_FOOT=6;
  TORQUE_KILOPOUND_FORCE_INCH=7;
  TORQUE_MEGANEWTON_CENTIMETER=8;
  TORQUE_MEGANEWTON_METER=9;
  TORQUE_MEGANEWTON_MILLIMETER=10;
  TORQUE_MEGAPOUND_FORCE_FOOT=11;
  TORQUE_MEGAPOUND_FORCE_INCH=12;
  TORQUE_NEWTON_CENTIMETER=13;
  TORQUE_NEWTON_METER=14;
  TORQUE_NEWTON_MILLIMETER=15;
  TORQUE_POUND_FORCE_FOOT=16;
  TORQUE_POUND_FORCE_INCH=17;
  TORQUE_TONNE_FORCE_CENTIMETER=18;
  TORQUE_TONNE_FORCE_METER=19;
  TORQUE_TONNE_FORCE_MILLIMETER=20;
}

//
// TorquePerLength units.
enum TorquePerLengthUnit {
  TORQUEPERLENGTH_KILOGRAM_FORCE_CENTIMETER_PER_METER=0;
  TORQUEPERLENGTH_KILOGRAM_FORCE_METER_PER_METER=1;
  TORQUEPERLENGTH_KILOGRAM_FORCE_MILLIMETER_PER_METER=2;
  TORQUEPERLENGTH_KILONEWTON_CENTIMETER_PER_METER=3;
  TORQUEPERLENGTH_KILONEWTON_METER_PER_METER=4;
  TORQUEPERLENGTH_KILONEWTON_MILLIMETER_PER_METER=5;
  TORQUEPERLENGTH_KILOPOUND_FORCE_FOOT_PER_FOOT=6;
  TORQUEPERLENGTH_KILOPOUND_FORCE_INCH_PER_FOOT=7;
  TORQUEPERLENGTH_MEGANEWTON_CENTIMETER_PER_METER=8;
  TORQUEPERLENGTH_MEGANEWTON_METER_PER_METER=9;
  TORQUEPERLENGTH_MEGANEWTON_MILLIMETER_PER_METER=10;
  TORQUEPERLENGTH_MEGAPOUND_FORCE_FOOT_PER_FOOT=11;
  TORQUEPERLENGTH_MEGAPOUND_FORCE_INCH_PER_FOOT=12;
  TORQUEPERLENGTH_NEWTON_CENTIMETER_PER_METER=13;
  TORQUEPERLENGTH_NEWTON_METER_PER_METER=14;
  TORQUEPERLENGTH_NEWTON_MILLIMETER_PER_METER=15;
  TORQUEPERLENGTH_POUND_FORCE_FOOT_PER_FOOT=16;
  TORQUEPERLENGTH_POUND_FORCE_INCH_PER_FOOT=17;
  TORQUEPERLENGTH_TONNE_FORCE_CENTIMETER_PER_METER=18;
  TORQUEPERLENGTH_TONNE_FORCE_METER_PER_METER=19;
  TORQUEPERLENGTH_TONNE_FORCE_MILLIMETER_PER_METER=20;
}

//
// Volume units.
enum VolumeUnit {
  VOLUME_ACRE_FOOT=0;
  VOLUME_AU_TABLESPOON=1;
  VOLUME_CENTILITER=2;
  VOLUME_CUBIC_CENTIMETER=3;
  VOLUME_CUBIC_DECIMETER=4;
  VOLUME_CUBIC_FOOT=5;
  VOLUME_CUBIC_HECTOMETER=6;
  VOLUME_CUBIC_INCH=7;
  VOLUME_CUBIC_KILOMETER=8;
  VOLUME_CUBIC_METER=9;
  VOLUME_CUBIC_MICROMETER=10;
  VOLUME_CUBIC_MILE=11;
  VOLUME_CUBIC_MILLIMETER=12;
  VOLUME_CUBIC_YARD=13;
  VOLUME_DECILITER=14;
  VOLUME_HECTOCUBIC_FOOT=15;
  VOLUME_HECTOCUBIC_METER=16;
  VOLUME_HECTOLITER=17;
  VOLUME_IMPERIAL_BEER_BARREL=18;
  VOLUME_IMPERIAL_GALLON=19;
  VOLUME_IMPERIAL_OUNCE=20;
  VOLUME_IMPERIAL_PINT=21;
  VOLUME_KILOCUBIC_FOOT=22;
  VOLUME_KILOCUBIC_METER=23;
  VOLUME_KILOIMPERIAL_GALLON=24;
  VOLUME_KILOLITER=25;
  VOLUME_KILOUS_GALLON=26;
  VOLUME_LITER=27;
  VOLUME_MEGACUBIC_FOOT=28;
  VOLUME_MEGAIMPERIAL_GALLON=29;
  VOLUME_MEGALITER=30;
  VOLUME_MEGAUS_GALLON=31;
  VOLUME_METRIC_CUP=32;
  VOLUME_METRIC_TEASPOON=33;
  VOLUME_MICROLITER=34;
  VOLUME_MILLILITER=35;
  VOLUME_OIL_BARREL=36;
  VOLUME_UK_TABLESPOON=37;
  VOLUME_US_BEER_BARREL=38;
  VOLUME_US_CUSTOMARY_CUP=39;
  VOLUME_US_GALLON=40;
  VOLUME_US_LEGAL_CUP=41;
  VOLUME_US_OUNCE=42;
  VOLUME_US_PINT=43;
  VOLUME_US_QUART=44;
  VOLUME_US_TABLESPOON=45;
  VOLUME_US_TEASPOON=46;
}

//
// VolumeConcentration units.
enum VolumeConcentrationUnit {
  VOLUMECONCENTRATION_CENTILITERS_PER_LITER=0;
  VOLUMECONCENTRATION_CENTILITERS_PER_MILILITER=1;
  VOLUMECONCENTRATION_DECILITERS_PER_LITER=2;
  VOLUMECONCENTRATION_DECILITERS_PER_MILILITER=3;
  VOLUMECONCENTRATION_DECIMAL_FRACTION=4;
  VOLUMECONCENTRATION_LITERS_PER_LITER=5;
  VOLUMECONCENTRATION_LITERS_PER_MILILITER=6;
  VOLUMECONCENTRATION_MICROLITERS_PER_LITER=7;
  VOLUMECONCENTRATION_MICROLITERS_PER_MILILITER=8;
  VOLUMECONCENTRATION_MILLILITERS_PER_LITER=9;
  VOLUMECONCENTRATION_MILLILITERS_PER_MILILITER=10;
  VOLUMECONCENTRATION_NANOLITERS_PER_LITER=11;
  VOLUMECONCENTRATION_NANOLITERS_PER_MILILITER=12;
  VOLUMECONCENTRATION_PART_PER_BILLION=13;
  VOLUMECONCENTRATION_PART_PER_MILLION=14;
  VOLUMECONCENTRATION_PART_PER_THOUSAND=15;
  VOLUMECONCENTRATION_PART_PER_TRILLION=16;
  VOLUMECONCENTRATION_PERCENT=17;
  VOLUMECONCENTRATION_PICOLITERS_PER_LITER=18;
  VOLUMECONCENTRATION_PICOLITERS_PER_MILILITER=19;
}

//
// VolumeFlow units.
enum VolumeFlowUnit {
  VOLUMEFLOW_ACRE_FOOT_PER_DAY=0;
  VOLUMEFLOW_ACRE_FOOT_PER_HOUR=1;
  VOLUMEFLOW_ACRE_FOOT_PER_MINUTE=2;
  VOLUMEFLOW_ACRE_FOOT_PER_SECOND=3;
  VOLUMEFLOW_CENTILITER_PER_DAY=4;
  VOLUMEFLOW_CENTILITER_PER_MINUTE=5;
  VOLUMEFLOW_CUBIC_DECIMETER_PER_MINUTE=6;
  VOLUMEFLOW_CUBIC_FOOT_PER_HOUR=7;
  VOLUMEFLOW_CUBIC_FOOT_PER_MINUTE=8;
  VOLUMEFLOW_CUBIC_FOOT_PER_SECOND=9;
  VOLUMEFLOW_CUBIC_METER_PER_DAY=10;
  VOLUMEFLOW_CUBIC_METER_PER_HOUR=11;
  VOLUMEFLOW_CUBIC_METER_PER_MINUTE=12;
  VOLUMEFLOW_CUBIC_METER_PER_SECOND=13;
  VOLUMEFLOW_CUBIC_MILLIMETER_PER_SECOND=14;
  VOLUMEFLOW_CUBIC_YARD_PER_DAY=15;
  VOLUMEFLOW_CUBIC_YARD_PER_HOUR=16;
  VOLUMEFLOW_CUBIC_YARD_PER_MINUTE=17;
  VOLUMEFLOW_CUBIC_YARD_PER_SECOND=18;
  VOLUMEFLOW_DECILITER_PER_DAY=19;
  VOLUMEFLOW_DECILITER_PER_MINUTE=20;
  VOLUMEFLOW_KILOLITER_PER_DAY=21;
  VOLUMEFLOW_KILOLITER_PER_MINUTE=22;
  VOLUMEFLOW_KILOUS_GALLON_PER_MINUTE=23;
  VOLUMEFLOW_LITER_PER_DAY=24;
  VOLUMEFLOW_LITER_PER_HOUR=25;
  VOLUMEFLOW_LITER_PER_MINUTE=26;
  VOLUMEFLOW_LITER_PER_SECOND=27;
  VOLUMEFLOW_MEGALITER_PER_DAY=28;
  VOLUMEFLOW_MEGAUK_GALLON_PER_SECOND=29;
  VOLUMEFLOW_MICROLITER_PER_DAY=30;
  VOLUMEFLOW_MICROLITER_PER_MINUTE=31;
  VOLUMEFLOW_MILLILITER_PER_DAY=32;
  VOLUMEFLOW_MILLILITER_PER_MINUTE=33;
  VOLUMEFLOW_MILLION_US_GALLONS_PER_DAY=34;
  VOLUMEFLOW_NANOLITER_PER_DAY=35;
  VOLUMEFLOW_NANOLITER_PER_MINUTE=36;
  VOLUMEFLOW_OIL_BARREL_PER_DAY=37;
  VOLUMEFLOW_OIL_BARREL_PER_HOUR=38;
  VOLUMEFLOW_OIL_BARREL_PER_MINUTE=39;
  VOLUMEFLOW_OIL_BARREL_PER_SECOND=40;
  VOLUMEFLOW_UK_GALLON_PER_DAY=41;
  VOLUMEFLOW_UK_GALLON_PER_MINUTE=42;
  VOLUMEFLOW_UK_GALLON_PER_SECOND=43;
  VOLUMEFLOW_US_GALLON_PER_DAY=44;
  VOLUMEFLOW_US_GALLON_PER_HOUR=45;
  VOLUMEFLOW_US_GALLON_PER_MINUTE=46;
  VOLUMEFLOW_US_GALLON_PER_SECOND=47;
}

//
// VolumePerLength units.
enum VolumePerLengthUnit {
  VOLUMEPERLENGTH_CUBIC_METER_PER_METER=0;
  VOLUMEPERLENGTH_CUBIC_YARD_PER_FOOT=1;
  VOLUMEPERLENGTH_CUBIC_YARD_PER_US_SURVEY_FOOT=2;
  VOLUMEPERLENGTH_LITER_PER_KILOMETER=3;
  VOLUMEPERLENGTH_LITER_PER_METER=4;
  VOLUMEPERLENGTH_LITER_PER_MILLIMETER=5;
  VOLUMEPERLENGTH_OIL_BARREL_PER_FOOT=6;
}

//
// WarpingMomentOfInertia units.
enum WarpingMomentOfInertiaUnit {
  WARPINGMOMENTOFINERTIA_CENTIMETER_TO_THE_SIXTH=0;
  WARPINGMOMENTOFINERTIA_DECIMETER_TO_THE_SIXTH=1;
  WARPINGMOMENTOFINERTIA_FOOT_TO_THE_SIXTH=2;
  WARPINGMOMENTOFINERTIA_INCH_TO_THE_SIXTH=3;
  WARPINGMOMENTOFINERTIA_METER_TO_THE_SIXTH=4;
  WARPINGMOMENTOFINERTIA_MILLIMETER_TO_THE_SIXTH=5;
}
