// Copyright 2025, ANSYS Inc. Unauthorized use, distribution or duplication is prohibited.
syntax = "proto3";
package ansys.api.discovery.v1;

option csharp_namespace = "Ansys.Api.Discovery.V1";


enum LogsTarget{
  LOGSTARGET_CLIENT = 0;
  LOGSTARGET_PATH = 1;
}

enum LogsPeriodType{
  LOGSPERIODTIME_CURRENT = 0;
  LOGSPERIODTIME_PAST = 1;
  LOGSPERIODTIME_ALL = 2;
}

enum BackendType{
  BACKENDTYPE_DISCOVERY = 0;
  BACKENDTYPE_SPACECLAIM = 1;
  BACKENDTYPE_WINDOWS_DMS = 2;
  BACKENDTYPE_LINUX_DMS = 3;
  BACKENDTYPE_CORE_SERVICE_WINDOWS = 4;
  BACKENDTYPE_CORE_SERVICE_LINUX = 5;
  BACKENDTYPE_DISCOVERY_HEADLESS = 6;
}

enum InputParameterType{
  INPUT_PARAMETERS_TYPE_PHYSICS_QUANTITY=0;
  INPUT_PARAMETERS_TYPE_DRIVING_DIMENSION=1;
  INPUT_PARAMETERS_TYPE_HISTORY_TRACK=2;
  INPUT_PARAMETERS_TYPE_PHYSICS_MATERIAL=3;
  UNKNOWN=4;
}

enum MonikerCompressionMethod {
  MONIKERCOMPRESSIONMETHOD_FULL = 0;
  MONIKERCOMPRESSIONMETHOD_COMPRESSED = 1;
  MONIKERCOMPRESSIONMETHOD_OBJECT_PATH = 2;
}

enum PersistentIdType {
  PERSISTENTIDTYPE_PNAME = 0;
  PERSISTENTIDTYPE_PRIME_ID = 700;
}

enum BodyExportFormat {
  BODYEXPORTFORMAT_PARASOLID_TEXT = 0;
  BODYEXPORTFORMAT_PARASOLID_BINARY = 1;
}

enum ImageFormat {
  IMAGEFORMAT_PNG = 0;
  IMAGEFORMAT_JPEG = 1;
}

enum WindowView {
  WINDOWVIEW_TOP = 0;
  WINDOWVIEW_BOTTOM = 1;
  WINDOWVIEW_LEFT = 2;
  WINDOWVIEW_RIGHT = 3;
  WINDOWVIEW_FRONT = 4;
  WINDOWVIEW_BACK = 5;
  WINDOWVIEW_ISOMETRIC = 6;
  WINDOWVIEW_TRIMETRIC = 7;
  WINDOWVIEW_FIT = 8;
}

enum FileFormat {
  FILEFORMAT_ACIS_TEXT = 0;
  FILEFORMAT_ACIS_BINARY = 1;
  FILEFORMAT_PARASOLID_TEXT = 2;
  FILEFORMAT_PARASOLID_BINARY = 3;
  FILEFORMAT_STEP = 4;
  FILEFORMAT_FMD = 5;
  FILEFORMAT_IGES = 6;
  FILEFORMAT_PMDB = 7;
  FILEFORMAT_DISCO = 8;
  FILEFORMAT_STRIDE = 9;
  FILEFORMAT_SCDOC = 10;
  FILEFORMAT_SCDOCX = 11;
  FILEFORMAT_JT_OPEN = 12;
  FILEFORMAT_VDA = 13;
  FILEFORMAT_RHINO = 14;
  FILEFORMAT_SKETCH_UP = 15;
  FILEFORMAT_PDF_GEOMETRY = 16;
  FILEFORMAT_PDF_FACETS = 17;
}

//
// The automatic tracking states.
enum AutomaticTrackingState {
  AUTOMATICTRACKINGSTATE_ON = 0;
  AUTOMATICTRACKINGSTATE_OFF = 1;
}