// Copyright 2025, ANSYS Inc. Unauthorized use, distribution or duplication is prohibited.
syntax = "proto3";
package ansys.api.discovery.v0.conditions.symmetry;

import "ansys/api/dbu/v0/dbumodels.proto";
import "ansys/api/discovery/v0/discoverymodels.proto";

option csharp_namespace = "Ansys.Api.Discovery.V0.Conditions";

service Symmetry
{
  //Symmetry condition methods
  rpc CreateSymmetry(SymmetryCreationRequest) returns (SymmetryCreationResponse);

  rpc ChangeSymmetryLocation(ChangeLocationRequest) returns(ChangeResponse);
}

// Symmetry
message SymmetryCreationRequest{
  ScopedCreationData creation_data = 1;
}

message SymmetryCreationResponse{
  CreationResponse condition_response = 1;
  SymmetryDefinition condition_data = 2;
}


message SymmetryDefinition {
  ansys.api.dbu.v0.PhysicsEntityIdentifier id = 1;
  ansys.api.dbu.v0.PhysicsEntityIdentifier parent_id = 2;
  string label = 3;
  repeated string locations = 4;
  bool suppressed = 5;
}