// Copyright 2025, ANSYS Inc. Unauthorized use, distribution or duplication is prohibited.
syntax = "proto3";

package ansys.api.discovery.v0.unsupported;

import "ansys/api/dbu/v0/dbumodels.proto";
import "ansys/api/discovery/v0/results.proto";
import "google/protobuf/empty.proto";

option csharp_namespace = "Ansys.Api.Discovery.V0.Unsupported";

service Unsupported {

  // Exports Live results in byte array form.
  rpc ExportResultsToOpenVDBMemory(VariableExportRequest) returns(ByteArrayResponse);

  // Exports Live results to file.
  rpc ExportResultsToOpenVDBFile(VariableExportRequestToFile) returns(ansys.api.dbu.v0.RequestResult);

  // Gets max and min value from the legend
  rpc GetLegendMaximumValue(google.protobuf.Empty) returns(DoubleValueResponse);
  rpc GetLegendMinimumValue(google.protobuf.Empty) returns(DoubleValueResponse);
  
}

message VariableExportRequest {
  repeated ansys.api.discovery.v0.results.ResultVariable result_variables = 1;
}

message VariableExportRequestToFile {
  repeated ansys.api.discovery.v0.results.ResultVariable result_variables = 1;
  string file_path = 2;
}

message ByteArrayResponse {
  bytes bytes = 1;
  bool success = 2;
}

message DoubleValueResponse {
  double value = 1;
  bool success = 2;
}