// Copyright 2025, ANSYS Inc. Unauthorized use, distribution or duplication is prohibited.
syntax = "proto3";
package ansys.api.discovery.v0.conditions.solidtemperature;

import "ansys/api/dbu/v0/dbumodels.proto";
import "ansys/api/discovery/v0/discoverymodels.proto";

option csharp_namespace = "Ansys.Api.Discovery.V0.Conditions";

service SolidTemperature
{
  rpc CreateTemperatureVolumetric(TemperatureCreationRequest) returns (TemperatureCreationResponse);

  rpc CreateTemperatureSurface(TemperatureCreationRequest) returns (TemperatureCreationResponse);

  rpc ChangeTemperatureLocation(ChangeLocationExtendedRequest) returns(ChangeResponse);

  rpc ChangeTemperatureMagnitude(ChangeQuantityRequest) returns(ChangeResponse);
}

//Requests and responses
message TemperatureCreationRequest{
  ScopedCreationData creation_data = 1;
  Quantity temperature = 2;
}

message TemperatureCreationResponse{
  CreationResponse condition_response = 1;
  TemperatureDefinition condition_data = 2;
}

// Definitions
message TemperatureDefinition {
  ansys.api.dbu.v0.PhysicsEntityIdentifier id = 1;
  ansys.api.dbu.v0.PhysicsEntityIdentifier parent_id = 2;
  string label = 3;
  repeated string locations = 4;
  bool suppressed = 5;
  Quantity magnitude = 6;
}