// Copyright 2025, ANSYS Inc. Unauthorized use, distribution or duplication is prohibited.
syntax = "proto3";
package ansys.api.discovery.v0.conditions.fluidinitialtemperature;

import "ansys/api/discovery/v0/discoverymodels.proto";

option csharp_namespace = "Ansys.Api.Discovery.V0.Conditions";

service FluidInitialTemperature
{
  rpc ChangeTemperatureMagnitude(ChangeQuantityRequest) returns(ChangeResponse);
}